import com.visibleworkings.trace.Trace;
import com.visibleworkings.trace.TraceController;
import java.util.Properties;
import java.io.File;

// Test different kinds of pathnames.
public class Dir {

    private static void deleteIfExists(String pathname) {
        File f = new File(pathname);
        if (f.exists()) {
            if (f.delete() == false) {
                System.out.println("WARNING: could not delete " + pathname);
            }
        }
    }

    private static void check(String pathname) {
        File f = new File(pathname);

        if (f.exists() == false) {
            System.out.println("====== FAILURE: " + pathname + " does not exist.");
        }
    }
        

    public static void main(String[] args) {


        // TEST 1 - absolute tag with drive letter
        String dirWinDrive = "c:\\temp";
        System.out.println("TEST 1: Starting with logfile Tag1.txt in " + dirWinDrive);

        String expected = "c:\\temp\\Tag1.txt";
        deleteIfExists(expected);

        Properties p = new Properties();
        p.setProperty("TraceLog_tag", "tag1");
        p.setProperty("TraceLog_dir", dirWinDrive);
        TraceController.start(p);
        
        Trace.trace.worldm("Started with " + dirWinDrive);
        check(expected);



        // TEST 2 - absolute tag.
        String dirWin = "\\temp";
        if (new File(dirWin).isAbsolute()) {
            System.out.println("TEST 2: Reopening with logfile Tag2.txt in " + dirWin);

            expected = "\\temp\\Tag2.txt";
            deleteIfExists(expected);

            Trace.trace.worldm("Reopening with " + dirWin);
            TraceController.setProperty("TraceLog_tag", "tag2");
            TraceController.setProperty("TraceLog_dir", dirWin);
            TraceController.setProperty("TraceLog_reopen", "true");

            Trace.trace.worldm("Did it work?");
            check(expected);
            
        } else {
            System.out.println("TEST 2: Skipping Tag2.txt.");
            System.out.println("This VM thinks " + dirWin + " is not absolute.");
        }
        
        
        // TEST 3 - absolute name with drive letter
        String nameWinDrive = "c:\\temp\\foo.bar";
        System.out.println("TEST 3: Reopening with logfile " + nameWinDrive);

        expected = "c:\\temp\\foo.bar";
        deleteIfExists(expected);
        
        TraceController.setProperty("TraceLog_name", nameWinDrive);
        TraceController.setProperty("TraceLog_reopen", "true");
        
        Trace.trace.worldm("Started with " + nameWinDrive);
        check(expected);



        // TEST 4 - absolute name
        String nameWin = "\\temp\\foo.bar";
        if (new File(nameWin).isAbsolute()) {
            System.out.println("TEST 4: Reopening with logfile " + nameWin);

            expected = "\\temp\\foo.bar";
            deleteIfExists(expected);

            Trace.trace.worldm("Reopening with " + nameWin);
            TraceController.setProperty("TraceLog_name", nameWin);
            TraceController.setProperty("TraceLog_reopen", "true");
            Trace.trace.worldm("Did it work?");

            check(expected);
            
        } else {
            System.out.println("TEST 4: Skipping " + nameWin);
            System.out.println("This VM thinks it is not absolute.");
        }
        
        
        // TEST 5 - relative tag
        String tagWinSubdir = "SUBDIR";
        System.out.println("TEST 5: Reopening Tag5.txt in " + tagWinSubdir);

        expected = "SUBDIR\\Tag5.txt";
        deleteIfExists(expected);
    
        TraceController.setProperty("TraceLog_tag", "tag5");
        TraceController.setProperty("TraceLog_dir", "SUBDIR");
        TraceController.setProperty("TraceLog_reopen", "true");
        
        Trace.trace.worldm("Started with " + tagWinSubdir);
        check(expected);


        // TEST 6 - relative name
        String nameWinSubdir = "foo.bar.name";
        System.out.println("TEST 6: Reopening " + nameWinSubdir + " in SUBDIR");

        expected = "SUBDIR\\foo.bar.name";
        deleteIfExists(expected);

        TraceController.setProperty("TraceLog_dir", "SUBDIR");
        TraceController.setProperty("TraceLog_name", nameWinSubdir);
        TraceController.setProperty("TraceLog_reopen", "true");
        
        Trace.trace.worldm("Started with " + nameWinSubdir);
        check(expected);
    }
}
