package com.visibleworkings.trace;

import junit.framework.*;
import java.io.File;
import java.io.IOException;
import java.util.Properties;

public class TestBackup extends TestCase {


	public TestBackup(String name) {
		super(name);
	}

	protected void setUp() {
        Properties p = new Properties();
        p.setProperty("TraceLog_size", "5000");
        p.setProperty("TraceLog_tag", "TestBackupGap");
        TraceController.start(p); 
	}

	public static Test suite() {
		return new TestSuite(TestBackup.class);
	}


    public void testGap() throws IOException {
        // if a 000 file and a 002 backup file exist, the backup is
        // supposed to be 003. The gap at 001 should remain.

        (new File("TestBackupGap.000.txt")).createNewFile();
        (new File("TestBackupGap.001.txt")).delete();
        (new File("TestBackupGap.002.txt")).createNewFile();
        (new File("TestBackupGap.003.txt")).delete();
        (new File("TestBackupGap.004.txt")).delete();
        (new File("TestBackupGap.005.txt")).delete();
        (new File("TestBackupGap.txt")).delete();

        for (int i = 0; i < 80; i++) {
            Trace.trace.worldm("Hello, world");
        }
        assert(!(new File("TestBackupGap.001.txt").exists()));
        assert((new File("TestBackupGap.002.txt").exists()));

        // The gap can be at the very beginning (000), and it is still
        // ignored. So with no 000 and a 001, the backup should be 002.
        (new File("Test000.000.txt")).delete();
        (new File("Test000.001.txt")).createNewFile();
        (new File("Test000.002.txt")).delete();
        (new File("Test000.003.txt")).delete();
        (new File("Test000.004.txt")).delete();
        (new File("Test000.005.txt")).delete();
        (new File("Test000.txt")).delete();
        
        TraceController.setProperty("TraceLog_tag", "Test000");
        TraceController.setProperty("Tracelog_reopen", "true");
        for (int i = 0; i < 80; i++) {
            Trace.trace.worldm("Hello, world");
        }
        assert((!new File("Test000.000.txt").exists()));
        assert((new File("Test000.002.txt").exists()));
    }



}
