package com.visibleworkings.trace;

import junit.framework.*;
import java.io.File;
import java.util.List;
import java.io.IOException;

/*
files are ordered correctly
 */

public class TestTraceLogList extends TestCase {


	public TestTraceLogList(String name) {
		super(name);
	}

	protected void setUp() {
	}

	public static Test suite() {
		return new TestSuite(TestTraceLogList.class);
	}

    void iofail(String tag, File dir, Exception e) {
        System.out.println("Test error: " + tag + " in " + dir + ": " + e.getMessage());
        fail("Test error - see previous message.");
    }

    // Test that just checks length of list, not contents.
    public void simpleTestSkeleton(String tag, int expectedLength) { 
        File here = new File(System.getProperty("user.dir"));
        try {
            List l = (new TraceLogList(here, tag)).convertToMessages();
            // System.out.println(l + "---> " + l.size());
            assert(l.size() == expectedLength);
        } catch (IOException e) { iofail(tag, here, e); }
    }

    // Test that expects a problem.
    public void errorTestSkeleton(String dir, String tag) { 
        File here = new File(dir);
        try {
            List l = (new TraceLogList(here, tag)).convertToMessages();
            fail("This point should not be reached.");
        } catch (IOException e) {
            // any IOexception is OK.
            // System.out.println(e.getMessage());
        } 
    }

    // One matching file containing one entry
    public void testOneFile() {
        simpleTestSkeleton("data-TraceLogList-oneFile", 1);
    }

    // One matching file containing no entries
    public void testNoFiles() {
        simpleTestSkeleton("data-TraceLogList-noFiles", 0);
    }

    // Two matching files containing more than one entry.
    public void testSeveral() {
        simpleTestSkeleton("data-TraceLogList-several", 6);
    }

    // No such directory
    public void testNoSuchDir() {
        errorTestSkeleton("nosuchdir", "data-TraceLogList-oneFile");
    }

    // No such file
    public void testNoSuchFile() {
        errorTestSkeleton(System.getProperty("user.dir"),
                          "no-such-file");
    }

    // The tag must be in the beginning of the filename.
    public void testHeaderOnly() {
        errorTestSkeleton(System.getProperty("user.dir"),
                          "ata-TraceLogList-oneFile");
    }

    // Test that checks parsing of a single line.
    public void testParsing() { 
        File here = new File(System.getProperty("user.dir"));
        String tag = "data-TraceLogList-oneFile";
        try {
            List l = (new TraceLogList(here, tag)).convertToMessages();
            assert(l.size() == 1);
            TraceParsedMessage msg = (TraceParsedMessage) l.get(0);
            assertEquals("2001", msg.year);
            assertEquals("02", msg.month);
            assertEquals("22", msg.day);
            assertEquals("11", msg.hour);
            assertEquals("44", msg.minute);
            assertEquals("02", msg.second);
            assertEquals("262", msg.milli);
            assertEquals("InstallTest.main", msg.method);
            assertEquals("InstallTest.java", msg.file);
            assertEquals("15", msg.line);
            assertEquals("ERR", msg.level);
            assertEquals("InstallTest", msg.subsystem);
            assertEquals("Here is a trace message at the ERROR level.", msg.message);
        } catch (IOException e) { iofail(tag, here, e); }
    }



    // Some pretty incomplete parse error tests.



    // Parsing of a file with a missing line.
    public void testMissingLine() { 
        File here = new File(System.getProperty("user.dir"));
        String tag = "data-TraceLogList-missingLine";
        try {
            List l = (new TraceLogList(here, tag)).convertToMessages();
            fail("This should not be reached.");
        } catch (IOException e) {
            assert(e.getMessage().indexOf("Partial message") != -1);
        }
    }

    // Parsing of a file with a truncated first line
    public void testTruncatedLine() { 
        File here = new File(System.getProperty("user.dir"));
        String tag = "data-TraceLogList-truncatedLine";
        try {
            List l = (new TraceLogList(here, tag)).convertToMessages();
            fail("This should not be reached.");
        } catch (IOException e) {
            // System.out.println(e.getMessage());
            assert(e.getMessage().indexOf("This trace message is garbled") != -1);
        }
    }

}

